==> vermouth-0.9.1.tar.gz: vermouth-0.9.1/vermouth/tests/datafiles.py <==
# Copyright 2018 University of Groningen
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from pathlib import Path

try:
    import pkg_resources
except ImportError:
    import os
    TEST_DATA = os.path.join(os.path.dirname(__file__), 'data')
    del os
else:
    TEST_DATA = Path(pkg_resources.resource_filename('vermouth.tests', 'data'))
    del pkg_resources

# PDB files with a single molecule
PDB_PROTEIN = TEST_DATA / '1bta.pdb'
PDB_PARTIALLY_PROTEIN = TEST_DATA / '1bta_mutated.pdb'  # LYS replaced by UNK
PDB_NOT_PROTEIN = TEST_DATA / 'heme.pdb'
PDB_ALA5 = TEST_DATA / 'ala5.pdb'
PDB_ALA5_CG = TEST_DATA / 'ala5_cg.pdb'
PDB_TRI_ALANINE = TEST_DATA / 'tri_alanine.pdb'

# Full PDB files
PDB_CYS = TEST_DATA / '2QWO.pdb'  # Contains cystein bridges
PDB_HB = TEST_DATA / '2dn2.pdb'  # Hemoglobin with heme and 2*2 protein chains
PDB_MULTIMODEL = TEST_DATA / '6E8W.pdb'  # HIV-1, 15 models

# DNA
SHORT_DNA = TEST_DATA / 'dna-short.pdb'

DSSP_OUTPUT = TEST_DATA / 'dssp_1bta.ssd'

# Test force fields
FF_UNIVERSAL_TEST = TEST_DATA / 'force_fields' / 'universal-test'
FF_PEPPLANE = TEST_DATA / 'force_fields' / 'pepplane'
FF_MARTINI_TEST = TEST_DATA / 'force_fields' / 'martini-test'

# Mappings
MAP_UNIVERSAL_TEST_PEPPLANE = TEST_DATA / 'mappings' / 'universal-test'


# Clean the namespace so only the data file variables can be imported.
# An other option would be to define __all__, but it is easy to forget to add
# a variable in that list.
del Path

==> vermouth-0.14.0.tar.gz: vermouth-0.14.0/vermouth/tests/datafiles.py <==
# Copyright 2018 University of Groningen
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from pathlib import Path

try:
    import pkg_resources
except ImportError:
    import os
    TEST_DATA = os.path.join(os.path.dirname(__file__), 'data')
    del os
else:
    TEST_DATA = Path(pkg_resources.resource_filename('vermouth.tests', 'data'))
    del pkg_resources

# PDB files with a single molecule
PDB_PROTEIN = TEST_DATA / '1bta.pdb'
PDB_PARTIALLY_PROTEIN = TEST_DATA / '1bta_mutated.pdb'  # LYS replaced by UNK
PDB_NOT_PROTEIN = TEST_DATA / 'heme.pdb'
PDB_ALA5 = TEST_DATA / 'ala5.pdb'
PDB_ALA5_CG = TEST_DATA / 'ala5_cg.pdb'
PDB_TRI_ALANINE = TEST_DATA / 'tri_alanine.pdb'

# Full PDB files
PDB_CYS = TEST_DATA / '2QWO.pdb'  # Contains cystein bridges
PDB_HB = TEST_DATA / '2dn2.pdb'  # Hemoglobin with heme and 2*2 protein chains
PDB_MULTIMODEL = TEST_DATA / '6E8W.pdb'  # HIV-1, 15 models

# DNA
SHORT_DNA = TEST_DATA / 'dna-short.pdb'

DSSP_OUTPUT = TEST_DATA / 'dssp_tests' / 'dssp_1bta.ssd'
DSSP_SS_OUTPUT = TEST_DATA / 'dssp_tests'

# Test force fields
FF_UNIVERSAL_TEST = TEST_DATA / 'force_fields' / 'universal-test'
FF_PEPPLANE = TEST_DATA / 'force_fields' / 'pepplane'
FF_MARTINI_TEST = TEST_DATA / 'force_fields' / 'martini-test'

# Mappings
MAP_UNIVERSAL_TEST_PEPPLANE = TEST_DATA / 'mappings' / 'universal-test'

# contact map
TEST_MOLECULE_CONTACT_MAP = TEST_DATA / 'test_molecule_contacts.out'

# cif file
CIF_PROTEIN = TEST_DATA / '1UBQ.cif'
CIF_NO_CELL = TEST_DATA / '1UBQ_nocell_occupancy.cif'
CIF_PDB_COMPARE = TEST_DATA / '1UBQ.pdb'
CIF_MULTI = TEST_DATA / 'multiple.cif'
CIF_MISSING_RESNAME = TEST_DATA / 'cif_missing_resname.cif'
CIF_MISSING_ATOMNAME = TEST_DATA / 'cif_missing_atomname.cif'


# Clean the namespace so only the data file variables can be imported.
# An other option would be to define __all__, but it is easy to forget to add
# a variable in that list.
del Path
